#define COMPILE_DL_XDEBUG 1
#define HAVE_DLFCN_H 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_INTTYPES_H 1
#define HAVE_MEMORY_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_POLL_H 1
#define HAVE_STDINT_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRINGS_H 1
#define HAVE_STRING_H 1
#define HAVE_SYS_POLL_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_UNISTD_H 1
#define HAVE_XDEBUG 1
#define HAVE_XDEBUG_CLOCK_GETTIME 1
#define HAVE_XDEBUG_CLOCK_GETTIME_NSEC_NP 0
